==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/atlantis/dialogs_de.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Siehe da!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Ach nee!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("Wer hätte das gedacht?!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("So eine Fahrlässigkeit!")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Tausende sind umgekommen, die ganze Stadt ist deswegen in den Wellen verschwunden.")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Ein gezogener Stöpsel.")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Ein peinlicher Fehltritt.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("Was machen wir damit?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Wir können versuchen, ihn wieder reinzustecken.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("Und dann trinken wir das Wasser aus, was reingelaufen ist, oder was?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens` heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Wir können ihn wieder reinstecken, als Zeichen unserer Achtung gegenüber den heldenhaften Bemühungen der Einwohner, die Stadt über Wasser zu halten.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.` The Providence itself unplugged that hole. Just imagine you`d hear such things at home. Day by day.")
dialogStr("Wovon? \"Wo läufst Du hin? Ich muss acht Schwerter bestellen.\" Die Vorsehung selbst hat den Stöpsel gezogen. Stell dir einfach vor, du würdest solche Sachen zuhause hören. Tag für Tag.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Und außerdem: Wird hier je irgendwer herkommen? Nur Tintenfische werden ihn ab und zu anknabbern.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Wir werden uns danach besser fühlen.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Wir werden uns danach schlechter fühlen. Denkst du, der Chef wird das glauben? Der riesige gezogene Stöpsel. Und was habt ihr damit gemacht? Wir haben ihn wieder reingesteckt. Ha, ha, ha.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Du könntest Recht haben. Vielleicht wäre es besser ihn mitzunehmen.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Das denke ich auch.")


dialogId("sp-v-dotoho", "font_big", "Let `s get to work.")
dialogStr("An die Arbeit.")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("Und was ist, wenn wir den Stöpsel einfach dalassen?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Was würde die Agentur sagen?")


dialogId("sp-v-jedno", "font_big", "I don`t think I mind what the boss is going to think about me.")
dialogStr("Ich denke, mir ist egal, was der Chef über mich denkt.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Warte. Wir kriegen das raus.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Der verflixte Stöpsel. Und was, wenn wir uns einfach was ausdenken?")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Was denn, zum Beispiel?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Nun, wir könnten behaupten, dass die Stadt nie wirklich existiert hat.")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Nun, wir könnten sagen, dass die Stadt wegen der arktischen Eisschmelze untergegangen ist.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Zum Beispiel könnte ein Erdbeben die Stadt versenkt haben.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Zum Beispiel könnte eine Flutwelle die Stadt versenkt haben.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Wir könnten behaupten, dass in der Stadtmitte ein Vulkan ausgebrochen ist.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Das ist blöder Quatsch.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Diesmal ist unser Ziel, den Stöpsel hier rauszukriegen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/atlantis/dialogs_de.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Siehe da!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Ach nee!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("Wer hätte das gedacht?!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("So eine Fahrlässigkeit!")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Tausende sind umgekommen, die ganze Stadt ist deswegen in den Wellen verschwunden.")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Ein gezogener Stöpsel.")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Ein peinlicher Fehltritt.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("Was machen wir damit?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Wir können versuchen, ihn wieder reinzustecken.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("Und dann trinken wir das Wasser aus, was reingelaufen ist, oder was?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens’ heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Wir können ihn wieder reinstecken, als Zeichen unserer Achtung gegenüber den heldenhaften Bemühungen der Einwohner, die Stadt über Wasser zu halten.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.’ The Providence itself unplugged that hole. Just imagine you’d hear such things at home. Day by day.")
dialogStr("Wovon? \"Wo läufst Du hin? Ich muss acht Schwerter bestellen.\" Die Vorsehung selbst hat den Stöpsel gezogen. Stell dir einfach vor, du würdest solche Sachen zuhause hören. Tag für Tag.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Und außerdem: Wird hier je irgendwer herkommen? Nur Tintenfische werden ihn ab und zu anknabbern.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Wir werden uns danach besser fühlen.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Wir werden uns danach schlechter fühlen. Denkst du, der Chef wird das glauben? Der riesige gezogene Stöpsel. Und was habt ihr damit gemacht? Wir haben ihn wieder reingesteckt. Ha, ha, ha.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Du könntest Recht haben. Vielleicht wäre es besser ihn mitzunehmen.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Das denke ich auch.")


dialogId("sp-v-dotoho", "font_big", "Let ’s get to work.")
dialogStr("An die Arbeit.")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("Und was ist, wenn wir den Stöpsel einfach dalassen?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Was würde die Agentur sagen?")


dialogId("sp-v-jedno", "font_big", "I don’t think I mind what the boss is going to think about me.")
dialogStr("Ich denke, mir ist egal, was der Chef über mich denkt.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Warte. Wir kriegen das raus.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Der verflixte Stöpsel. Und was, wenn wir uns einfach was ausdenken?")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Was denn, zum Beispiel?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Nun, wir könnten behaupten, dass die Stadt nie wirklich existiert hat.")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Nun, wir könnten sagen, dass die Stadt wegen der arktischen Eisschmelze untergegangen ist.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Zum Beispiel könnte ein Erdbeben die Stadt versenkt haben.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Zum Beispiel könnte eine Flutwelle die Stadt versenkt haben.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Wir könnten behaupten, dass in der Stadtmitte ein Vulkan ausgebrochen ist.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Das ist blöder Quatsch.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Diesmal ist unser Ziel, den Stöpsel hier rauszukriegen.")
